class Flamethrower {
	constructor(game, x, y, r){
		this.game = game;
		
		// Rendering
		this.texture = game.textures.projectiles;
		this.atlas = game.atlas.projectiles.flamethrower;
		
		// Scale
		this.scale = 1.5;
		this.width = this.scale * 3;
		this.height = this.scale * 3;
		
		// Physics
		this.x = x;
		this.y = y;
		this.radius = 0;
		
		this.collision = {
			with: [ Alien ],
			width: 0,
			height: 0,
			radius: 0,
			offsetX: 0,
			offsetY: 0,
			hitRadius: 2,
			isDud: Math.random() > 0.3,
			
			piercing: false,
			
			reaction: burnReaction
		};
		
		var angle = 20;
		this.r = r + (Math.random() * 2 * angle - angle);
		this.vr = (Math.random() * 2 - 1);
		
		// Flamethrower
		this.maxLife = 0.36 * 2.5;
		this.life = this.maxLife;
		this.isAlive = true;
		
		this.speed = 1.2;
	}
	
	
	update(delta){
		var speed = this.speed * this.life / this.maxLife;
		
		this.x += speed * Math.sin(this.r/180*Math.PI) * delta * 60;
		this.y += speed * -Math.cos(this.r/180*Math.PI) * delta * 60;
		this.r += this.vr;
		
		doCollision(this);
		
		if(!this.isAlive) return this.life = 0;
		return this.life -= delta;
	}
	
	
	draw(context, textures, atlas){
		var texture = this.texture,
			map = this.atlas[Math.floor((1 - this.life/this.maxLife) * this.atlas.length)],
			mult = 1.5;
		
		context.save();
		context.translate(this.x, this.y);
		context.rotate(this.r/180*Math.PI);
		
		context.globalAlpha = this.life / this.maxLife;
		context.drawImage(texture, map[0], map[1], map[2], map[3], -map[2]/2 * this.scale, -map[3]/2 * this.scale, map[2] * this.scale, map[3] * this.scale);
		
		context.restore();
	}
}
